summaryrefslogtreecommitdiff
path: root/vendor/github.com/vbauerster/mpb/v5/decor/any.go
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/github.com/vbauerster/mpb/v5/decor/any.go')
-rw-r--r--vendor/github.com/vbauerster/mpb/v5/decor/any.go14
1 files changed, 7 insertions, 7 deletions
diff --git a/vendor/github.com/vbauerster/mpb/v5/decor/any.go b/vendor/github.com/vbauerster/mpb/v5/decor/any.go
index bf9cf51a5..39518f594 100644
--- a/vendor/github.com/vbauerster/mpb/v5/decor/any.go
+++ b/vendor/github.com/vbauerster/mpb/v5/decor/any.go
@@ -1,21 +1,21 @@
package decor
// Any decorator displays text, that can be changed during decorator's
// lifetime via provided func call back.
//
-// `f` call back which provides string to display
+// `fn` DecorFunc callback
//
// `wcc` optional WC config
//
-func Any(f func(*Statistics) string, wcc ...WC) Decorator {
- return &any{initWC(wcc...), f}
+func Any(fn DecorFunc, wcc ...WC) Decorator {
+ return &any{initWC(wcc...), fn}
}
type any struct {
WC
- f func(*Statistics) string
+ fn DecorFunc
}
-func (d *any) Decor(s *Statistics) string {
- return d.FormatMsg(d.f(s))
+func (d *any) Decor(s Statistics) string {
+ return d.FormatMsg(d.fn(s))
}
@@ -1,21 +1,21 @@
package decor
// Any decorator displays text, that can be changed during decorator's
-// lifetime via provided func call back.
+// lifetime via provided DecorFunc.
//